Musicbox
Author: Wouter van Wijk

- Home
- Now Playing
- Queue
- Playlists
- Browse
- Streams
- Search
- Alarm Clock
- Fullscreen
- Settings
- System
- Volume

Close

###

####

Close

####

- Play All
- Play
- Play Track Next
- Add Track to Bottom of Queue
- Add All to Bottom of Queue

- Play
- Play Track Next
- Add Track to Bottom of Queue
- Add all to Bottom of Queue
- Show Album
- Show Artist

## Artists

- Play
- Remove from Queue
- Show Album
- Show Artist

## Artists

Save current queue to a playlist.

Overwrite existing playlist with same name?

# Musicbox

#### Now Playing

#### Queue

#### Playlists

#### Browse

#### Streams

#### Search

#### Alarm Clock

#### Settings

#### System

###

-

Position

#### Playlists

Back

#### Browse

#####

#### Play Queue

###

#####

###

#### Search

Search for artists, albums, or specific tracks.

#### Artists

#### Albums

#### Tracks

#### Streams

Play a specific stream/track and optionally save it to your favourites.